@@ -1,4 +1,23 @@
-A = [#[-2, -3], 
+numVars = 2
+numCons = 3
+A = [[-2, -3], 
+     [-4, -2], 
+     [-3, -4],
+     ]
+
+b = [-5, 
+     -15, 
+     -20,
+      ]
+
+x_u = [9,
+       6,
+       ]
+
+integerIndices = [0, 1]
+
+'''
+A = [[-2, -3], 
      [-4, -2], 
      [-3, -4], 
      [1, 0], 
@@ -6,19 +25,23 @@ A = [#[-2, -3],
      [-1, 0], 
      [0, -1]]
 
-b = [#-5, 
+b = [-5, 
      -15, 
      -20, 
      9, 
      6, 
      0, 
      0]
+'''
 
 c = [20,
-     15]
+     15,
+     ]
 
 obj_val = 100
 
+sense = ('Min', '<=')
+
 points = None
 rays = []
 
